@@ -25,10 +25,14 @@ def load_modules() -> None:
     are located. This function imports these and by doing that, makes them accessible to 
     `Message.__subclasses__()` which is later used in serve()->_register_models_to_server()
     '''
-    modules = settings.modules
-    for module in modules:
-        __import__(module + '.' + 'models')
-
+    if hasattr(settings, 'modules'):
+        modules = settings.modules
+        for module in modules:
+            __import__(module + '.' + 'models')
+    try: # check, if there is a models.py in root (a shortcut)
+        __import__('models')
+    except:
+        pass # 
 
 def serve(): # -> NoReturn:
     '''
